@@ -90,7 +90,7 @@ while (time < $s) {
     $F->box({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY), 'filled' => 1});
 }
 
-print_it($F, 'Gradient Box Test');
+print_it($F, 'Vertical Gradient Box Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -116,6 +116,33 @@ while (time < $s) {
         }
     );
 } ## end while (time < $s)
+print_it($F, 'Horizontal Gradient Box Test');
+$s = time + $factor;
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->box(
+        {
+            'x'        => rand($XX),
+            'y'        => rand($YY),
+            'xx'       => rand($XX),
+            'yy'       => rand($YY),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
+        }
+    );
+} ## end while (time < $s)
 
 print_it($F, 'Rounded Box Test');
 $s = time + $factor;
@@ -131,7 +158,7 @@ while (time < $s) {
     $F->box({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY), 'radius' => rand($XX / 16), 'filled' => 1});
 }
 
-print_it($F, 'Gradient Rounded Box Test');
+print_it($F, 'Vertical Gradient Rounded Box Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -159,6 +186,35 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
+print_it($F, 'Horizontal Gradient Rounded Box Test');
+$s = time + $factor;
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->box(
+        {
+            'x'        => rand($XX),
+            'y'        => rand($YY),
+            'xx'       => rand($XX),
+            'yy'       => rand($YY),
+            'radius'   => rand($XX / 16),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
+        }
+    );
+} ## end while (time < $s)
+
 print_it($F, 'Circle Test');
 $s = time + $factor;
 while (time < $s) {
@@ -173,7 +229,7 @@ while (time < $s) {
     $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'filled' => 1});
 }
 
-print_it($F, 'Gradient Circle Test');
+print_it($F, 'Vertical Gradient Circle Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -199,6 +255,33 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
+print_it($F, 'Horizontal Gradient Circle Test');
+$s = time + $factor;
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->circle(
+        {
+            'x'        => rand($XX),
+            'y'        => rand($YY),
+            'radius'   => rand($center_x),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
+        }
+    );
+} ## end while (time < $s)
+
 print_it($F, 'Arc Test');
 $s = time + $factor;
 while (time < $s) {
@@ -220,7 +303,7 @@ while (time < $s) {
     $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
-print_it($F, 'Gradient Filled Pie Test');
+print_it($F, 'Vertical Gradient Filled Pie Test');
 $s = time + ($factor * 2);
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -247,6 +330,34 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
+print_it($F, 'Horizontal Gradient Filled Pie Test');
+$s = time + ($factor * 2);
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->filled_pie(
+        {
+            'x'             => rand($XX),
+            'y'             => rand($YY),
+            'radius'        => rand($center_y),
+            'start_degrees' => rand(360),
+            'end_degrees'   => rand(360),
+            'gradient'      => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
+        }
+    );
+} ## end while (time < $s)
+
 print_it($F, 'Ellipse Test');
 $s = time + $factor;
 while (time < $s) {
@@ -261,7 +372,7 @@ while (time < $s) {
     $F->ellipse({'x' => rand($XX), 'y' => rand($YY), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1});
 }
 
-print_it($F, 'Gradient Ellipse Test');
+print_it($F, 'Vertical Gradient Ellipse Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -288,6 +399,34 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
+print_it($F, 'Horizontal Gradient Ellipse Test');
+$s = time + $factor;
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->ellipse(
+        {
+            'x'        => rand($XX),
+            'y'        => rand($YY),
+            'xradius'  => rand($center_x),
+            'yradius'  => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
+        }
+    );
+} ## end while (time < $s)
+
 print_it($F, 'Polygon Test');
 $s = time + $factor;
 while (time < $s) {
@@ -302,7 +441,7 @@ while (time < $s) {
     $F->polygon({'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)], 'filled' => 1});
 }
 
-print_it($F, 'Gradient Polygon Test');
+print_it($F, 'Vertical Gradient Polygon Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -326,6 +465,31 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
+print_it($F, 'Horizontal Gradient Polygon Test');
+$s = time + $factor;
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->polygon(
+        {
+            'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)],
+            'filled'      => 1,
+            'gradient'    => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
+        }
+    );
+} ## end while (time < $s)
+
 print_it($F, 'Testing Bezier Curves');
 
 $s = time + $factor;
